@@ -28,6 +28,7 @@ pub struct PermissionArgs {
   host: Option<String>,
   variable: Option<String>,
   command: Option<String>,
+  library: Option<String>,
 }
 
 pub fn op_query_permission(
@@ -49,7 +50,7 @@ pub fn op_query_permission(
     ),
     "env" => permissions.env.query(args.variable.as_deref()),
     "run" => permissions.run.query(args.command.as_deref()),
-    "plugin" => permissions.plugin.query(),
+    "ffi" => permissions.ffi.query(args.library.as_deref()),
     "hrtime" => permissions.hrtime.query(),
     n => {
       return Err(custom_error(
@@ -80,7 +81,7 @@ pub fn op_revoke_permission(
     ),
     "env" => permissions.env.revoke(args.variable.as_deref()),
     "run" => permissions.run.revoke(args.command.as_deref()),
-    "plugin" => permissions.plugin.revoke(),
+    "ffi" => permissions.ffi.revoke(args.library.as_deref()),
     "hrtime" => permissions.hrtime.revoke(),
     n => {
       return Err(custom_error(
@@ -111,7 +112,7 @@ pub fn op_request_permission(
     ),
     "env" => permissions.env.request(args.variable.as_deref()),
     "run" => permissions.run.request(args.command.as_deref()),
-    "plugin" => permissions.plugin.request(),
+    "ffi" => permissions.ffi.request(args.library.as_deref()),
     "hrtime" => permissions.hrtime.request(),
     n => {
       return Err(custom_error(
